let firstLoad=true
let app = new Vue({
    el: "#app",
    data: {
        isDark: null,
        themeColor: "",
        screenName: "",
        prompt: "",
        profilePhoto: "",
        showIndex: -1,
        clickable: true,
        hasHistory: false,
        clickableHistory: true,
        historyText: "",
        emptyText: "",
        emptyToastShow: false,
        turnToAgent: "",
        txtNode: null,
        conversationData: []
    },
    computed: {
        bodyColor: function () {
            if (!this.themeColor) {
                return ""
            }
            return { '--color': this.themeColor }
        },
        imgColor: function () {
            if (!this.themeColor) {
                return ""
            }
            return { fill: this.themeColor }
        },
        textColor: function () {
            if (!this.themeColor) {
                return ""
            }
            return { color: this.themeColor }
        }
    },
    filters: {
        // 处理文件大小
        formatFileSize: function (fileSize) {
            if (fileSize < 1024) {
                return fileSize + 'B';
            } else if (fileSize < (1024 * 1024)) {
                let temp = fileSize / 1024;
                temp = temp.toFixed(2);
                return temp + 'KB';
            } else if (fileSize < (1024 * 1024 * 1024)) {
                let temp = fileSize / (1024 * 1024);
                temp = temp.toFixed(2);
                return temp + 'MB';
            } else {
                let temp = fileSize / (1024 * 1024 * 1024);
                temp = temp.toFixed(2);
                return temp + 'GB';
            }
        },
        // 对文件名进行...处理
        formatFileName: function (fileName) {
            let cLen = 0;
            let tmpIndex = -1;
            let maxLen = 44;
            for (let i = 0; i < fileName.length; i++) {
                let c = fileName.charAt(i);
                if (/^[\u0000-\u00ff]$/.test(c)) {
                    cLen++;
                } else {
                    cLen += 2;
                }
                if (cLen > maxLen) {
                    tmpIndex = i;
                    break;
                }
            }
            if (tmpIndex !== -1) {
                let index = fileName.lastIndexOf(".");
                if (index !== -1) {
                    let preStr = fileName.substring(0, tmpIndex);
                    let suffixStr = fileName.substring(index - 1);
                    return preStr + '...' + suffixStr;
                }
            }
            return fileName;
        }
    },
    methods: {
        // 切换分类展开
        showList: function (index) {
            index === this.showIndex ? this.showIndex = -1 : this.showIndex = index;
        },
        // 点击问题
        askItem: function (item) {
            window.bridge.setQuestion(JSON.stringify(item));
        },
        // 转人工
        toService: function () {
            this.showTips = true;
            //this.clickable = false;
            window.bridge.turnToAgent();
        },
        // 点击点赞或者踩
        likeClick: function (item, type) {
            if (!item.evaluateResult) {
                let optionId = 1;
                if (type === 0) {
                    optionId = 2;
                    this.$set(item, 'evaluateResult', 'unlike');
                } else {
                    this.$set(item, 'evaluateResult', 'like');
                }
                window.bridge.robotServiceEvaluation(JSON.stringify({ option_id: optionId }));
            }
        },
        // 获取历史记录
        getHistory: function () {
            this.clickableHistory = false;
            window.bridge.readHistory();
        },
        // 双击打开文件
        openFile: function (item) {
            window.bridge.openChatFile(item.content);
        },
        // 右击显示菜单
        showMenu: function (event, item) {
            let json = { screenX: event.screenX, screenY: event.screenY, content: item.content, flag: 'file' };
            window.bridge.setClickedPoints(JSON.stringify(json));
        },
        // 文本右击获取菜单
        openTxtMenu: function (event, parentName) {
            let node = event.target;
            if (node) {
                node = node.closest(parentName);
            }
            this.txtNode = node;
            let text = '';
            if (window.getSelection) {
                text = window.getSelection().toString();
            } else if (document.selection) {
                text = document.selection.createRange().toString();
            }
            let json = { screenX: event.screenX, screenY: event.screenY, copyTxt: text, flag: 'text' };
            window.bridge.setClickedPoints(JSON.stringify(json));
        }
    }
})
// QWebChannel初始化
function fromWebToCpp() {
    new QWebChannel(qt.webChannelTransport, function (channel){
        window.bridge = channel.objects.objectChannel;
        window.bridge.registerFinish();
    });
}
// 获取初始化列表数据
function conversationData(data) {
    if (!data) {
        return;
    }
    // 设置第一条信息展示友情提示
    if (app.conversationData && app.conversationData.length <= 0) {
        data.showPrompt = true; 
    }
    else if(firstLoad){
      app.$nextTick(function () {
        firstLoad=false
        window.bridge.jsLoadfinish()
    })
    }
    app.conversationData.push(data);
    // 将滚动条滚动到底部
    let timeOut = setTimeout(() => {
        clearTimeout(timeOut);
        let kfContent = document.getElementsByClassName("kf-content");
        if (kfContent && kfContent.length) {
            kfContent[0].scrollTop = kfContent[0].scrollHeight;
        }
    }, 300);
}

// 获取其他初始化数据(头像、名称等)
function otherData(data) {
    if (!data) {
        return;
    }
    app.prompt = data.prompt;
    app.historyText = data.historyText;
    app.profilePhoto = data.icon;
    app.screenName = data.name;
    app.hasHistory = data.hasHistory;
    app.turnToAgent = data.turnToAgent;
}
// 切换主题
function setTheme(theme) {
    if (theme === 'black') {
        app.isDark = true;
    } else {
        app.isDark = false;
    }
}
// 系统主题色
function setThemeColor(color) {
    if (!color) {
        return;
    }
    app.themeColor = color;
}
// 接收消息
function recvMessage(data) {
    if (!data) {
        return;
    }
    if (data.direct === 'Send') {
        data.sendStatus = 'fail';
    } else if (data.type !== 'File' && data.type !== 'Image') {
        let content =  _convertLinkContent(data.content);
        data.content = content;
        // 将处理后的结果发送给qt端保存
        window.bridge.setContent(content);
    }
    app.conversationData.push(data);
    let timeOut = setTimeout(() => {
        clearTimeout(timeOut);
        let kfContent = document.getElementsByClassName("kf-content");
        if (kfContent && kfContent.length) {
            kfContent[0].scrollTop = kfContent[0].scrollHeight;
        }
    }, 300);
}
// 发送消息的状态:成功/失败
function sendStatus (data) {
    if (!data || !data.messageId) {
        return;
    }
    for (let i = app.conversationData.length - 1; i >= 0; i--) {
        let item = app.conversationData[i];
        if (item.messageId === data.messageId) {
            item.sendStatus = data.status;
            break;
        }
    }
}
// 获取历史记录
function historyData(res) {
    if (!res) {
        return;
    }
    let { data, hasHistory } = res;
    // 对历史数据进行处理
    for (let i = 0; i < data.length; i++) {
        let item = data[i];
        if (item.evaluate) {
            item.evaluateDisabled = true;
        }
        let index = app.conversationData.findIndex((oldItem) => {
            return (oldItem.datetime === item.datetime && oldItem.content === item.content);
        });
        if (index !== -1) {
            data.splice(i, 1);
            i--;
        }
    }
    app.hasHistory = hasHistory;
    app.conversationData.unshift(...data);
    app.clickableHistory = true;
    // 加载历史数据的同时保持滚动条不动
    let kfContent = document.getElementsByClassName("kf-content");
    let oldHeight = kfContent[0].scrollHeight;
    let timeOut = setTimeout(() => {
        clearTimeout(timeOut);
        kfContent[0].scrollTop =  kfContent[0].scrollHeight - oldHeight;
    }, 300);
}
// 获取转人工的状态码
function turnToAgentStatus(res) {
    if (!res) {
        return;
    }
    let data = app.conversationData;
    if (data && data.length) {
        let item = data[data.length - 1];
        let { time, status: msg, code } = res;
        if (code === 3000) {
            app.clickable = true;
        } else if (code === 2002) {
            app.clickable = true;
        }
        Vue.set(item, 'agentTime', time);
        Vue.set(item, 'agentMsg', msg);
        Vue.set(item, 'showTips', true);
        // 将滚动条滚动到底部
        let timeOut = setTimeout(() => {
            clearTimeout(timeOut);
            let kfContent = document.getElementsByClassName("kf-content");
            if (kfContent && kfContent.length) {
                kfContent[0].scrollTop = kfContent[0].scrollHeight;
            }
        }, 300);
    }
}
// 输入消息为空时触发
function messageEmptyToast(data) {
    if (!data) {
        return;
    }
    app.emptyText = data.popupmessage;
    app.emptyToastShow = true;
    let timeOut = setTimeout(() => {
        clearTimeout(timeOut);
        app.emptyToastShow = false;
    }, 500);
}
// 用浏览器打开链接地址
function openBrowser(url) {
    if (!url) {
        return;
    }
    window.bridge.openBrowser(url);
}
// 执行文本拷贝
function copyTxt(txt) {
    if (!txt) {
        return;
    }
    // 执行浏览器的复制命令
    let res = document.execCommand('Copy', false, null);
    console.log(res);
}
// 执行文本全选
function selectAllTxt () {
    let node = app.txtNode;
    if (!node) {
        return;
    }
    if (document.body.createTextRange) {
        let range = document.body.createTextRange();
        range.moveToElementText(node);
        range.select();
    } else if (window.getSelection) {
        let selection = window.getSelection();
        let range = document.createRange();
        range.selectNodeContents(node);
        selection.removeAllRanges();
        selection.addRange(range);
    }
}
// 对超链接处理
function _convertLinkContent(content) {
    if (!content) {
        return "";
    }
    let reg = /(http:\/\/|https:\/\/)((\w|=|\?|\.|\/|&|-)+)/ig;
    let res = reg.exec(content);
    if(res && res.length) {
        content = content.replace(reg, "<a href='javascript:void(0)' onclick='openBrowser(\"$1$2\")'>$1$2</a>");
    }
    return content;
}

function setWebClickNoable() {
    app.clickable = false
}
